OiRA

Help

1. Preparación
2. Implicación
3. Identificación + Evaluación
4. Plan de acción
   1. 1.1.1 Slips, trips and falls are not prevented.
   2. 1.1.2 Collisions, bumps, and jamming are not prevented.
   3. 1.1.4 Exposure to noise is neither prevented nor controlled.
   4. 1.1.6 Exposure to biological substances is neither prevented nor controlled
   5. Ω.1 The entrance floor is often wet
   6. Title of the first custom risk
   7. This is another custom risk added by the user
   - Atención
5. Informe
6. Grado de cumplimentación 9%

# Commercial guarding, Leicester

Tras haber identificado los riesgos, necesitará implantar un plan de acción para gestionar los riesgos. Para eliminar o reducir los riesgos deberá determinar las medidas preventivas o protectoras que se deben tomar.

Entre las cosas que se deben tener en cuenta en este paso están:

1. ¿Se puede evitar el riesgo? ¿Se puede eliminar completamente? Por ejemplo, se puede lograr:
   - pensando si la tarea o el trabajo es necesario
   - eliminando el peligro
2. Si algún riesgo no se puede evitar, ¿cómo se puede reducir hasta un nivel en que no afecte a la seguridad y salud de los implicados?

Una vez que haya decidido cómo eliminar o reducir un riesgo particular, describa las acciones específicas necesarias para lograrlo. Deberá incluir además detalles sobre el nivel de experiencia y/u otros requisitos necesarios para que dichas acciones sean efectivas.

Crear plan de acción

Scroll to top
Back

## action-plan-landing.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More